require 'json'

#
# Authentication model conatining token generation attributes
#
class Authentication
  attr_accessor :grant_type
  attr_accessor :username
  attr_accessor :password
  attr_accessor :token
  attr_accessor :refresh_token

  #
  # Inialise the authentication model
  #
  # @param [String] grant_type Token grant type
  # @param [String] username
  # @param [String] password
  # @param [String] token Bearer token
  # @param [String] refresh_token Refresh token
  #
  def initialize(grant_type: nil, username: nil, password: nil, token: nil, refresh_token: nil)
    self.grant_type = grant_type
    self.username = username
    self.password = password
    self.token = token
    self.refresh_token = refresh_token
  end

  #
  # Converts Authentication object to Hash and deletes null value fields
  #
  # @param [Refrence] options
  #
  # @return [Hash] Hash of authentication object
  #
  def as_json(options = {})
    hash_data = {
      grant_type: @grant_type,
      username: @username,
      password: @password,
      token: @token,
      refresh_token: @refresh_token
    }

    hash_data.delete_if { |k, v| v.nil? || v.empty? }
    hash_data
  end

  #
  # Gets Json represenatation of authentication object
  #
  # @param [Object] auth_data Authentication object
  #
  # @return [Json] Json represenatation of authentication object
  #
  def self.get_payload(auth_data)
    auth_data.as_json.to_json
  end

  #
  # Gets Json represenatation of authentication object with client details
  #
  # @param [Object] auth_data Authentication object
  #
  # @return [Json] Json represenatation of authentication object
  #
  def self.get_payload_with_client_info(auth_data)
    auth_data.as_json.merge!({ 'client_id' => ApplicationConfig.client_id, 'client_secret' => ApplicationConfig.client_secret }).to_json
  end
end
