require 'rest-client'
require 'json'
require_relative '../domain/authentication.rb'

#
# Authentication Service for token activies
#
class AuthenticationService
  #
  # Creates authentication token
  #
  # @param [object] auth_data Authentication object
  #
  # @return [Json] Response with brearer and refresh token
  #
  def self.create_authentication(auth_data)
    auth_payload = Authentication.get_payload_with_client_info(auth_data)
    RestClient::Request.execute(method: :post,
                                url: ApplicationConfig.get_url('create_authentication_path'),
                                payload: auth_payload,
                                headers: { 'Content-Type': 'application/json' })
  end

  #
  # Refresh authentication token
  #
  # @param [Object] auth_data Authentication object
  # @param [String] bearer_token
  #
  # @return [Json] Response with brearer and refresh token
  #
  def self.refresh_authentication_token(auth_data, bearer_token)
    auth_payload = Authentication.get_payload_with_client_info(auth_data)
    RestClient::Request.execute(method: :post,
                                url: ApplicationConfig.get_url('create_authentication_path'),
                                payload: auth_payload,
                                headers: { 'Content-Type': 'application/json',
                                           'Authorization': bearer_token })
  end

  #
  # Revokes authentication token
  #
  # @param [Object] auth_data Authentication object
  # @param [String] bearer_token
  #
  # @return [Json] Response with revoke message
  #
  def self.revoke_authentication_token(auth_data, bearer_token)
    auth_payload = Authentication.get_payload(auth_data)
    RestClient::Request.execute(method: :post,
                                url: ApplicationConfig.get_url('revoke_authentication_path'),
                                payload: auth_payload,
                                headers: { 'Content-Type': 'application/json',
                                           'Authorization': bearer_token })
  end
end
