require 'rest-client'
require 'json'
require_relative '../domain/application_config.rb'

#
# User Widget Service for widget display  based on user details
#
class UserWidgetService
  #
  # Displays own widgets
  #
  # @param [String] bearer_token
  #
  # @return [Json] Response containing list of own widgets
  #
  def self.get_private_widgets(bearer_token)
    RestClient::Request.execute(method: :get,
                                url: ApplicationConfig.get_url('own_widgets_path'),
                                headers: { 'Content-Type': 'application/json',
                                           params: { client_id: ApplicationConfig.client_id,
                                                     client_secret: ApplicationConfig.client_secret },
                                           'Authorization': bearer_token })
  end

  #
  # Displays own widget with search term
  #
  # @param [String] search_term
  # @param [String] bearer_token
  #
  # @return [Json] Response containing list of own widget by search term
  #
  def self.get_private_widgets_with_search_term(search_term, bearer_token)
    RestClient::Request.execute(method: :get,
                                url: ApplicationConfig.get_url('own_widgets_path'),
                                headers: { 'Content-Type': 'application/json',
                                           params: { client_id: ApplicationConfig.client_id,
                                                     client_secret: ApplicationConfig.client_secret,
                                                     term: search_term },
                                           'Authorization': bearer_token })
  end

  #
  # Displays widgets for given user id
  #
  # @param [String] user_id
  # @param [String] bearer_token
  #
  # @return [Json] Resopnse containing widgets list for given user id
  #
  def self.get_widgets_by_user_id(user_id, bearer_token)
    url_with_id = ApplicationConfig.get_url('widgets_by_user_id_path') + '/' + user_id.to_s + '/widgets'
    RestClient::Request.execute(method: :get,
                                url: url_with_id,
                                headers: { 'Content-Type': 'application/json',
                                           params: { client_id: ApplicationConfig.client_id,
                                                     client_secret: ApplicationConfig.client_secret },
                                           'Authorization': bearer_token })
  end

  #
  # Displays widgets for given user id and serach term
  #
  # @param [String] user_id
  # @param [String] search_term
  # @param [String] bearer_token
  #
  # @return [Json] Response contating widget details for user id and serach term
  #
  def self.get_widgets_by_user_id_with_search_term(user_id, search_term, bearer_token)
    url_with_id = ApplicationConfig.get_url('widgets_by_user_id_path') + '/' + user_id.to_s + '/widgets'
    RestClient::Request.execute(method: :get,
                                url: url_with_id,
                                headers: { 'Content-Type': 'application/json',
                                           params: { client_id: ApplicationConfig.client_id,
                                                     client_secret: ApplicationConfig.client_secret,
                                                     term: search_term },
                                           'Authorization': bearer_token })
  end
end
